@@ -51,9 +51,9 @@ class d3graph():
         Parameters
         ----------
         collision : float, (default: 0.5)
-            Nodes wants to prevent a collision. The higher the number, the more collisions are prevented.
+            Response of the network. Higher means that more collisions are prevented.
         charge : int, (default: 250)
-            Scaling/Response of the network. Towards zero becomes a more nervous network.
+            Edge length of the network. Towards zero becomes a dense network. Higher make edges longer.
         slider : typle [min: int, max: int]:, (default: [None, None])
             Slider is automatically set to the range of the edge weights.
         verbose : int, (default: 20)
@@ -65,6 +65,8 @@ class d3graph():
         None.
 
         """
+        # Cleaning
+        self._clean()
         # Some library compatibily checks
         library_compatibility_checks()
         # Set the logger
@@ -80,13 +82,15 @@ class d3graph():
         self.config['d3_script'] = os.path.abspath(os.path.join(self.config['curpath'], 'd3js/d3graphscript.js'))
         self.config['css'] = os.path.abspath(os.path.join(self.config['curpath'], 'd3js/style.css'))
 
-    def clean(self):
+    def _clean(self, clean_config=True):
         """Clean previous results to ensure correct working."""
         if hasattr(self, 'adjmat'): del self.adjmat
         if hasattr(self, 'node_properties'): del self.node_properties
         if hasattr(self, 'edge_properties'): del self.edge_properties
+        if hasattr(self, 'G'): del self.G
+        if clean_config and hasattr(self, 'config'): del self.config
 
-    def show(self, figsize=(1500, 800), title='d3graph', filepath='d3graph.html', showfig=True):
+    def show(self, figsize=(1500, 800), title='d3graph', filepath='d3graph.html', showfig=True, overwrite=True):
         """Build and show the graph.
 
         Parameters
@@ -99,13 +103,14 @@ class d3graph():
             File path to save the output
         showfig : bool, (default: True)
             Open the window to show the network.
+        overwrite : bool, (default: True)
+            Overwrite the existing html file.
 
         Returns
         -------
         None.
 
         """
-        time.sleep(0.5)
         self.config['figsize'] = figsize
         self.config['network_title'] = title
         # self.config['path'] = '' if filepath is None else filepath
@@ -119,21 +124,23 @@ class d3graph():
         # Create json
         json_data = json_create(self.G)
         # Create html with json file embedded
-        self.write_html(json_data)
+        self.write_html(json_data, overwrite=overwrite)
         # Open the webbrowser
         if self.config['showfig']:
+            # Sleeping is required to pevent overlapping windows
+            time.sleep(0.5)
             webbrowser.open(os.path.abspath(self.config['filepath']), new=2)
         # Return
         return self.G
 
-    def set_edge_properties(self, edge_distance=None, edge_distance_minmax=[None, None], directed=False):
+    def set_edge_properties(self, edge_distance=None, edge_distance_minmax=[1, 20], directed=False):
         """Edge properties.
 
         Parameters
         ----------
         edge_distance : Int (default: 30)
             Distance of nodes on the edges.
-            * 0: Weighted approach using edge weights in the adjadancy matrix. Weights are normalized between the edge_distance_minmax
+            * 0: Weighted approach using edge weights in the adjacancy matrix. Weights are normalized between the edge_distance_minmax
             * 80: Constant edge distance
         edge_distance_minmax : tuple(int,int), (default: [None,None])
             Weights are normalized between minimum and maximum
@@ -152,13 +159,16 @@ class d3graph():
         """
         self.config['directed'] = directed
         self.config['edge_distance'] = 30 if edge_distance is None else edge_distance
-        if edge_distance_minmax[0] is None: edge_distance_minmax[0]=1
-        if edge_distance_minmax[1] is None: edge_distance_minmax[1]=20
+        # if edge_distance_minmax[0] is None: edge_distance_minmax[0]=0
+        # if edge_distance_minmax[1] is None: edge_distance_minmax[1]=20
+        # self.config['slider'][0] = int(edge_distance_minmax[0])
+        # self.config['slider'][1] = int(edge_distance_minmax[1])
         self.config['edge_distance_minmax'] = edge_distance_minmax
         # edges to graph (G) (also works with lower versions of networkx)
         self.edge_properties = adjmat2dict(self.adjmat, min_weight=0, edge_distance_minmax=self.config['edge_distance_minmax'])
 
-    def set_node_properties(self, label=None, color='#000080', size=10, edge_color='#000000', edge_size=1, cmap='Set1'):
+
+    def set_node_properties(self, label=None, hover=None, color='#000080', size=10, edge_color='#000000', edge_size=1, cmap='Set1'):
         """Node properties.
 
         Parameters
@@ -215,7 +225,20 @@ class d3graph():
             label = self.adjmat.columns.astype(str)
         else:
             label = np.array([''] * nodecount)
-        if not (len(label)==nodecount): raise Exception(logger.warning("Node label must be of same length as the number of nodes"))
+        if not (len(label)==nodecount): raise Exception(logger.warning("[label] must be of same length as the number of nodes"))
+
+        # Hover text
+        if isinstance(hover, list):
+            hover = np.array(hover).astype(str)
+        elif 'numpy' in str(type(hover)):
+            pass
+        elif isinstance(hover, str):
+            hover = np.array([hover] * nodecount)
+        elif label is not None:
+            hover = label
+        else:
+            hover = np.array([''] * nodecount)
+        if not (len(hover)==nodecount): raise Exception(logger.warning("[Hover text] must be of same length as the number of nodes"))
 
         # Set node color
         if isinstance(color, list):
@@ -229,7 +252,7 @@ class d3graph():
         else:
             assert 'Node color not possible'
         color = _get_hexcolor(color, cmap=self.config['cmap'])
-        if not (len(color)==nodecount): raise Exception(logger.warning("Node color must be of same length as the number of nodes"))
+        if not (len(color)==nodecount): raise Exception(logger.warning("[color] must be of same length as the number of nodes"))
 
         # Set node color edge
         if isinstance(edge_color, list):
@@ -243,7 +266,7 @@ class d3graph():
         else:
             assert 'Node color edge not possible'
         edge_color = _get_hexcolor(edge_color, cmap=self.config['cmap'])
-        if not (len(edge_color)==nodecount): raise Exception(logger.warning("Node color edge must be of same length as the number of nodes"))
+        if not (len(edge_color)==nodecount): raise Exception(logger.warning("[edge_color] must be of same length as the number of nodes"))
 
         # Set node size
         if isinstance(size, list):
@@ -274,14 +297,16 @@ class d3graph():
 
         # Scale the sizes and get hex colors
         edge_size = _normalize_size(edge_size.reshape(-1, 1), 0.1, 4)
-        if not (len(edge_size)==nodecount): raise Exception(logger.warning("Node size edge must be of same length as the number of nodes"))
+        if not (len(edge_size)==nodecount): raise Exception(logger.warning("[edge_size] must be of same length as the number of nodes"))
 
         # Store in dict
         node_names = self.adjmat.columns.astype(str)
         self.node_properties = {}
         for i, node in enumerate(node_names):
             self.node_properties[node] = {
+                'name': node,
                 'label': label[i],
+                'hover': hover[i],
                 'color': color[i].astype(str),
                 'size': size[i],
                 'edge_size': edge_size[i],
@@ -297,29 +322,30 @@ class d3graph():
         """
         tmplist = [*self.G.edges.values()]
         edge_weight = list(map(lambda x: x['weight_scaled'], tmplist))
+        edge_weight = list(map(lambda x: x['weight'], tmplist))
 
-        if self.config['slider'] == [None, None]:
-            max_slider = np.ceil(np.max(edge_weight))
-            if len(np.unique(edge_weight))>1:
-                min_slider = np.maximum(np.floor(np.min(edge_weight)) - 1, 0)
-            else:
-                min_slider = 0
+        # if self.config['slider'] == [None, None]:
+        max_slider = np.ceil(np.max(edge_weight))
+        # max_slider = np.ceil(np.sort(edge_weight)[-2])
+        if len(np.unique(edge_weight))>1:
+            min_slider = np.maximum(np.floor(np.min(edge_weight)) - 1, 0)
         else:
-            assert len(self.config['slider'])==2, 'Slider must be of type [int, int]'
-            min_slider = self.config['slider'][0]
-            max_slider = self.config['slider'][1]
+            min_slider = 0
+        # else:
+            # assert len(self.config['slider'])==2, 'Slider must be of type [int, int]'
+            # min_slider = self.config['slider'][0]
+            # max_slider = self.config['slider'][1]
         # Store the slider range
-        logger.info('Slider range is set to [%g, %g]' %(min_slider, max_slider))
-        self.config['slider'] = [min_slider, max_slider]
+        self.config['slider'] = [int(min_slider), int(max_slider)]
+        logger.info('Slider range is set to [%g, %g]' %(self.config['slider'][0], self.config['slider'][1]))
 
     def graph(self, adjmat):
-        """Make interactive network in d3js.
+        """Process the adjacency matrix and set all properties to default.
 
         Description
         -----------
-        d3graph is a python library that is build on d3js and creates interactive and stand-alone networks.
-        The input data is a simple adjacency matrix for which the columns and indexes are the nodes and elements>0 the edges.
-        The ouput is a html file that is interactive and stand alone.
+        This function processes the adjacency matrix. The nodes are the column and index names.
+        An connect edge is seen in case vertices has has values larger than 0. The strenght of the edge is based on the vertices values.
 
         Parameters
         ----------
@@ -328,25 +354,24 @@ class d3graph():
 
         Examples
         --------
-        >>> from d3graph import d3graph, vec2adjmat
+        >>> from d3graph import d3graph
         >>>
-        >>> source = ['node A','node F','node B','node B','node B','node A','node C','node Z']
-        >>> target = ['node F','node B','node J','node F','node F','node M','node M','node A']
-        >>> weight = [5.56, 0.5, 0.64, 0.23, 0.9, 3.28, 0.5, 0.45]
-        >>>
-        >>> # Convert vector to adjacency matrix
-        >>> adjmat = vec2adjmat(source, target, weight=weight)
-        >>>
-        >>> Initialize the d3graph library
+        >>> # Initialize
         >>> d3 = d3graph()
-        >>> # Proces adjacency matrix
-        >>> d3.graph(adjmat)
-        >>> # Make the plot
-        >>> d3.show()
         >>>
-        >>> # Make changed in the node properties
-        >>> d3.set_node_properties(label=['node 1','node 2','node 3','node 4','node 5','node 6','node 7'], size=[10, 20, 10, 10, 15, 10, 5], color=adjmat.columns.values)
-        >>> # Make the plot
+        >>> # Load karate example
+        >>> adjmat, df = d3.import_example('karate')
+        >>>
+        >>> # Initialize
+        >>> d3.graph(adjmat)
+        >>>
+        >>> # Node properties
+        >>> d3.set_node_properties(label=df['label'].values, color=df['label'].values, size=df['degree'].values, edge_size=df['degree'].values, cmap='Set1')
+        >>>
+        >>> # Edge properties
+        >>> d3.set_edge_properties(directed=True)
+        >>>
+        >>> # Plot
         >>> d3.show()
 
         Returns
@@ -355,7 +380,7 @@ class d3graph():
 
         """
         # Clean readily fitted models to ensure correct results
-        self.clean()
+        self._clean(clean_config=False)
         # Checks
         self.adjmat = data_checks(adjmat.copy())
         # Set edge properties
@@ -363,7 +388,7 @@ class d3graph():
         # Set node properties
         self.set_node_properties()
 
-    def write_html(self, json_data):
+    def write_html(self, json_data, overwrite=True):
         """Write html.
 
         Parameters
@@ -393,6 +418,10 @@ class d3graph():
         index_file = Path(self.config['filepath'])
         logger.info('Write to path: [%s]' % index_file.absolute())
         # index_file.write_text(index_template.render(content))
+        if os.path.isfile(index_file):
+            if overwrite:
+                logger.info('File already exists and will be overwritten: [%s]' %(index_file))
+                os.remove(index_file)
         with open(index_file, "w", encoding="utf-8") as f:
             f.write(index_template.render(content))
 
@@ -429,6 +458,50 @@ class d3graph():
         logger.debug("filepath is set to [%s]" %(filepath))
         return filepath
 
+    def import_example(self, network='small'):
+        """Import example.
+
+        Parameters
+        ----------
+        network : str, optional
+            Import example adjacency matrix. The default is 'small'.
+
+        Returns
+        -------
+        adjmat : pd.DataFrame()
+
+        """
+        if network=='small':
+            source = ['node A', 'node F', 'node B', 'node B', 'node B', 'node A', 'node C', 'node Z']
+            target = ['node F', 'node B', 'node J', 'node F', 'node F', 'node M', 'node M', 'node A']
+            weight = [5.56, 0.5, 0.64, 0.23, 0.9, 3.28, 0.5, 0.45]
+            adjmat = vec2adjmat(source, target, weight=weight)
+            return adjmat
+        elif network=='bigbang':
+            source = ['Penny', 'Penny', 'Amy', 'Bernadette', 'Bernadette', 'Sheldon', 'Sheldon', 'Sheldon', 'Rajesh']
+            target = ['Leonard', 'Amy', 'Bernadette', 'Rajesh', 'Howard', 'Howard', 'Leonard', 'Amy', 'Penny']
+            weight = [5, 3, 2, 2, 5, 2, 3, 5, 2]
+            adjmat = vec2adjmat(source, target, weight=weight)
+            return adjmat
+        elif network=='karate':
+            G = nx.karate_club_graph()
+            adjmat = nx.adjacency_matrix(G).todense()
+            adjmat=pd.DataFrame(index=range(0, adjmat.shape[0]), data=adjmat, columns=range(0, adjmat.shape[0]))
+            adjmat.columns=adjmat.columns.astype(str)
+            adjmat.index=adjmat.index.astype(str)
+            adjmat.iloc[3, 4]=5
+            adjmat.iloc[4, 5]=6
+            adjmat.iloc[5, 6]=7
+
+            df = pd.DataFrame(index=adjmat.index)
+            df['degree']=np.array([*G.degree()])[:, 1]
+            label=[]
+            for i in range(0, len(G.nodes)):
+                label.append(G.nodes[i]['club'])
+            df['label'] = label
+
+            return adjmat, df
+
 
 # %%
 def set_logger(verbose=20):
@@ -475,12 +548,15 @@ def json_create(G):
 
     nodes = pd.DataFrame([*G.nodes.values()]).T.to_dict()
     nodes_new = [None] * len(nodes)
-    for i in range(0, len(nodes)):
+    for i, node in enumerate(nodes):
         nodes[i]['node_name'] = nodes[i].pop('label')
+        # nodes[i]['node_label'] = nodes[i].pop('label')
+        nodes[i]['node_hover'] = nodes[i].pop('hover')
         nodes[i]['node_color'] = nodes[i].pop('color')
         nodes[i]['node_size'] = nodes[i].pop('size')
         nodes[i]['node_size_edge'] = nodes[i].pop('edge_size')
         nodes[i]['node_color_edge'] = nodes[i].pop('edge_color')
+        # Combine all information into new list
         nodes_new[i] = nodes[i]
     data['nodes'] = nodes_new
 
@@ -488,7 +564,7 @@ def json_create(G):
 
 
 # %%  Convert adjacency matrix to vector
-def adjmat2dict(adjmat, min_weight=0, edge_distance_minmax=[1, 20]):
+def adjmat2dict(adjmat, min_weight=0, edge_distance_minmax=[1, 10]):
     """Convert adjacency matrix into vector with source and target.
 
     Parameters
